@@ -24,6 +24,8 @@ def encode_offset(stream: BinaryIO, offset: int):
 
 
 class ComplexView(SubtreeView):
+    __slots__ = ()
+
     def encode_bytes(self) -> bytes:
         stream = io.BytesIO()
         self.serialize(stream)
@@ -42,6 +44,7 @@ M = TypeVar('M', bound="MonoSubtreeView")
 
 
 class MonoSubtreeView(ColSequence, ComplexView):
+    __slots__ = ()
 
     def length(self) -> int:
         raise NotImplementedError
@@ -253,6 +256,8 @@ class MonoSubtreeView(ColSequence, ComplexView):
 
 
 class List(MonoSubtreeView):
+    __slots__ = ()
+
     def __new__(cls, *args, backing: Optional[Node] = None, hook: Optional[ViewHook] = None, **kwargs):
         if backing is not None:
             if len(args) != 0:
@@ -412,11 +417,13 @@ class List(MonoSubtreeView):
         self.set_backing(next_backing)
 
     def get(self, i: int) -> View:
+        i = int(i)
         if i < 0 or i >= self.length():
             raise IndexError
         return super().get(i)
 
     def set(self, i: int, v: View) -> None:
+        i = int(i)
         if i < 0 or i >= self.length():
             raise IndexError
         super().set(i, v)
@@ -491,6 +498,8 @@ class List(MonoSubtreeView):
 
 
 class Vector(MonoSubtreeView):
+    __slots__ = ()
+
     def __new__(cls, *args, backing: Optional[Node] = None, hook: Optional[ViewHook] = None, **kwargs):
         if backing is not None:
             if len(args) != 0:
@@ -580,11 +589,13 @@ class Vector(MonoSubtreeView):
         return out_typ
 
     def get(self, i: int) -> View:
+        i = int(i)
         if i < 0 or i >= self.__class__.vector_length():
             raise IndexError
         return super().get(i)
 
     def set(self, i: int, v: View) -> None:
+        i = int(i)
         if i < 0 or i >= self.__class__.vector_length():
             raise IndexError
         super().set(i, v)
@@ -671,6 +682,8 @@ class FieldOffset(NamedTuple):
 
 @runtime_checkable
 class _ContainerLike(Protocol):
+    __slots__ = ()
+
     @classmethod
     def fields(cls) -> Fields:
         ...
@@ -680,6 +693,8 @@ CV = TypeVar('CV', bound="Container")
 
 
 class _ContainerBase(ComplexView):
+    __slots__ = ()
+
     def __new__(cls, *args, backing: Optional[Node] = None, hook: Optional[ViewHook] = None,
                 append_nodes: Optional[PyList[Node]] = None, **kwargs):
         if backing is not None:
@@ -700,6 +715,7 @@ class _ContainerBase(ComplexView):
 
 class Container(_ContainerBase):
     _field_indices: Dict[str, int]
+    __slots__ = '_field_indices'
 
     def __new__(cls, *args, backing: Optional[Node] = None, hook: Optional[ViewHook] = None,
                 append_nodes: Optional[PyList[Node]] = None, **kwargs):
